# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKWatershedsPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkMorphologicalWatershedFromMarkersImageFilterPython
else:
    import _itkMorphologicalWatershedFromMarkersImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkImageToImageFilterAPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkVectorPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkCovariantVectorPython
import itk.itkPointPython
import itk.vnl_matrix_fixedPython
import itk.itkImagePython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.itkIndexPython
import itk.itkRGBAPixelPython
import itk.itkRGBPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkImageRegionPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkImageToImageFilterCommonPython

def itkMorphologicalWatershedFromMarkersImageFilterIF2ISS2_New():
    return itkMorphologicalWatershedFromMarkersImageFilterIF2ISS2.New()

class itkMorphologicalWatershedFromMarkersImageFilterIF2ISS2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF2ISS2):
    r"""Proxy of C++ itkMorphologicalWatershedFromMarkersImageFilterIF2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMorphologicalWatershedFromMarkersImageFilterIF2ISS2_Pointer"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMorphologicalWatershedFromMarkersImageFilterIF2ISS2_Pointer"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF2ISS2_Clone(self)

    def SetMarkerImage(self, input):
        r"""
        SetMarkerImage(self, input)

        Parameters
        ----------
        input: itkImageSS2 const *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF2ISS2_SetMarkerImage(self, input)

    def GetMarkerImage(self):
        r"""GetMarkerImage(self) -> itkImageSS2"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF2ISS2_GetMarkerImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageF2 const *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF2ISS2_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageSS2 const *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF2ISS2_SetInput2(self, input)

    def SetFullyConnected(self, _arg):
        r"""
        SetFullyConnected(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF2ISS2_SetFullyConnected(self, _arg)

    def GetFullyConnected(self):
        r"""GetFullyConnected(self) -> bool const &"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF2ISS2_GetFullyConnected(self)

    def FullyConnectedOn(self):
        r"""FullyConnectedOn(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF2ISS2_FullyConnectedOn(self)

    def FullyConnectedOff(self):
        r"""FullyConnectedOff(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF2ISS2_FullyConnectedOff(self)

    def SetMarkWatershedLine(self, _arg):
        r"""
        SetMarkWatershedLine(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF2ISS2_SetMarkWatershedLine(self, _arg)

    def GetMarkWatershedLine(self):
        r"""GetMarkWatershedLine(self) -> bool const &"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF2ISS2_GetMarkWatershedLine(self)

    def MarkWatershedLineOn(self):
        r"""MarkWatershedLineOn(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF2ISS2_MarkWatershedLineOn(self)

    def MarkWatershedLineOff(self):
        r"""MarkWatershedLineOff(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF2ISS2_MarkWatershedLineOff(self)
    __swig_destroy__ = _itkMorphologicalWatershedFromMarkersImageFilterPython.delete_itkMorphologicalWatershedFromMarkersImageFilterIF2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMorphologicalWatershedFromMarkersImageFilterIF2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMorphologicalWatershedFromMarkersImageFilterIF2ISS2

        Create a new object of the class itkMorphologicalWatershedFromMarkersImageFilterIF2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMorphologicalWatershedFromMarkersImageFilterIF2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMorphologicalWatershedFromMarkersImageFilterIF2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMorphologicalWatershedFromMarkersImageFilterIF2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMorphologicalWatershedFromMarkersImageFilterIF2ISS2 in _itkMorphologicalWatershedFromMarkersImageFilterPython:
_itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF2ISS2_swigregister(itkMorphologicalWatershedFromMarkersImageFilterIF2ISS2)

def itkMorphologicalWatershedFromMarkersImageFilterIF2IUC2_New():
    return itkMorphologicalWatershedFromMarkersImageFilterIF2IUC2.New()

class itkMorphologicalWatershedFromMarkersImageFilterIF2IUC2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF2IUC2):
    r"""Proxy of C++ itkMorphologicalWatershedFromMarkersImageFilterIF2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMorphologicalWatershedFromMarkersImageFilterIF2IUC2_Pointer"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMorphologicalWatershedFromMarkersImageFilterIF2IUC2_Pointer"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF2IUC2_Clone(self)

    def SetMarkerImage(self, input):
        r"""
        SetMarkerImage(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF2IUC2_SetMarkerImage(self, input)

    def GetMarkerImage(self):
        r"""GetMarkerImage(self) -> itkImageUC2"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF2IUC2_GetMarkerImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageF2 const *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF2IUC2_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF2IUC2_SetInput2(self, input)

    def SetFullyConnected(self, _arg):
        r"""
        SetFullyConnected(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF2IUC2_SetFullyConnected(self, _arg)

    def GetFullyConnected(self):
        r"""GetFullyConnected(self) -> bool const &"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF2IUC2_GetFullyConnected(self)

    def FullyConnectedOn(self):
        r"""FullyConnectedOn(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF2IUC2_FullyConnectedOn(self)

    def FullyConnectedOff(self):
        r"""FullyConnectedOff(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF2IUC2_FullyConnectedOff(self)

    def SetMarkWatershedLine(self, _arg):
        r"""
        SetMarkWatershedLine(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF2IUC2_SetMarkWatershedLine(self, _arg)

    def GetMarkWatershedLine(self):
        r"""GetMarkWatershedLine(self) -> bool const &"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF2IUC2_GetMarkWatershedLine(self)

    def MarkWatershedLineOn(self):
        r"""MarkWatershedLineOn(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF2IUC2_MarkWatershedLineOn(self)

    def MarkWatershedLineOff(self):
        r"""MarkWatershedLineOff(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF2IUC2_MarkWatershedLineOff(self)
    __swig_destroy__ = _itkMorphologicalWatershedFromMarkersImageFilterPython.delete_itkMorphologicalWatershedFromMarkersImageFilterIF2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMorphologicalWatershedFromMarkersImageFilterIF2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMorphologicalWatershedFromMarkersImageFilterIF2IUC2

        Create a new object of the class itkMorphologicalWatershedFromMarkersImageFilterIF2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMorphologicalWatershedFromMarkersImageFilterIF2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMorphologicalWatershedFromMarkersImageFilterIF2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMorphologicalWatershedFromMarkersImageFilterIF2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMorphologicalWatershedFromMarkersImageFilterIF2IUC2 in _itkMorphologicalWatershedFromMarkersImageFilterPython:
_itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF2IUC2_swigregister(itkMorphologicalWatershedFromMarkersImageFilterIF2IUC2)

def itkMorphologicalWatershedFromMarkersImageFilterIF3ISS3_New():
    return itkMorphologicalWatershedFromMarkersImageFilterIF3ISS3.New()

class itkMorphologicalWatershedFromMarkersImageFilterIF3ISS3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF3ISS3):
    r"""Proxy of C++ itkMorphologicalWatershedFromMarkersImageFilterIF3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMorphologicalWatershedFromMarkersImageFilterIF3ISS3_Pointer"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMorphologicalWatershedFromMarkersImageFilterIF3ISS3_Pointer"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF3ISS3_Clone(self)

    def SetMarkerImage(self, input):
        r"""
        SetMarkerImage(self, input)

        Parameters
        ----------
        input: itkImageSS3 const *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF3ISS3_SetMarkerImage(self, input)

    def GetMarkerImage(self):
        r"""GetMarkerImage(self) -> itkImageSS3"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF3ISS3_GetMarkerImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageF3 const *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF3ISS3_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageSS3 const *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF3ISS3_SetInput2(self, input)

    def SetFullyConnected(self, _arg):
        r"""
        SetFullyConnected(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF3ISS3_SetFullyConnected(self, _arg)

    def GetFullyConnected(self):
        r"""GetFullyConnected(self) -> bool const &"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF3ISS3_GetFullyConnected(self)

    def FullyConnectedOn(self):
        r"""FullyConnectedOn(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF3ISS3_FullyConnectedOn(self)

    def FullyConnectedOff(self):
        r"""FullyConnectedOff(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF3ISS3_FullyConnectedOff(self)

    def SetMarkWatershedLine(self, _arg):
        r"""
        SetMarkWatershedLine(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF3ISS3_SetMarkWatershedLine(self, _arg)

    def GetMarkWatershedLine(self):
        r"""GetMarkWatershedLine(self) -> bool const &"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF3ISS3_GetMarkWatershedLine(self)

    def MarkWatershedLineOn(self):
        r"""MarkWatershedLineOn(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF3ISS3_MarkWatershedLineOn(self)

    def MarkWatershedLineOff(self):
        r"""MarkWatershedLineOff(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF3ISS3_MarkWatershedLineOff(self)
    __swig_destroy__ = _itkMorphologicalWatershedFromMarkersImageFilterPython.delete_itkMorphologicalWatershedFromMarkersImageFilterIF3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMorphologicalWatershedFromMarkersImageFilterIF3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMorphologicalWatershedFromMarkersImageFilterIF3ISS3

        Create a new object of the class itkMorphologicalWatershedFromMarkersImageFilterIF3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMorphologicalWatershedFromMarkersImageFilterIF3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMorphologicalWatershedFromMarkersImageFilterIF3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMorphologicalWatershedFromMarkersImageFilterIF3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMorphologicalWatershedFromMarkersImageFilterIF3ISS3 in _itkMorphologicalWatershedFromMarkersImageFilterPython:
_itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF3ISS3_swigregister(itkMorphologicalWatershedFromMarkersImageFilterIF3ISS3)

def itkMorphologicalWatershedFromMarkersImageFilterIF3IUC3_New():
    return itkMorphologicalWatershedFromMarkersImageFilterIF3IUC3.New()

class itkMorphologicalWatershedFromMarkersImageFilterIF3IUC3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF3IUC3):
    r"""Proxy of C++ itkMorphologicalWatershedFromMarkersImageFilterIF3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMorphologicalWatershedFromMarkersImageFilterIF3IUC3_Pointer"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMorphologicalWatershedFromMarkersImageFilterIF3IUC3_Pointer"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF3IUC3_Clone(self)

    def SetMarkerImage(self, input):
        r"""
        SetMarkerImage(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF3IUC3_SetMarkerImage(self, input)

    def GetMarkerImage(self):
        r"""GetMarkerImage(self) -> itkImageUC3"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF3IUC3_GetMarkerImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageF3 const *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF3IUC3_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF3IUC3_SetInput2(self, input)

    def SetFullyConnected(self, _arg):
        r"""
        SetFullyConnected(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF3IUC3_SetFullyConnected(self, _arg)

    def GetFullyConnected(self):
        r"""GetFullyConnected(self) -> bool const &"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF3IUC3_GetFullyConnected(self)

    def FullyConnectedOn(self):
        r"""FullyConnectedOn(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF3IUC3_FullyConnectedOn(self)

    def FullyConnectedOff(self):
        r"""FullyConnectedOff(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF3IUC3_FullyConnectedOff(self)

    def SetMarkWatershedLine(self, _arg):
        r"""
        SetMarkWatershedLine(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF3IUC3_SetMarkWatershedLine(self, _arg)

    def GetMarkWatershedLine(self):
        r"""GetMarkWatershedLine(self) -> bool const &"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF3IUC3_GetMarkWatershedLine(self)

    def MarkWatershedLineOn(self):
        r"""MarkWatershedLineOn(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF3IUC3_MarkWatershedLineOn(self)

    def MarkWatershedLineOff(self):
        r"""MarkWatershedLineOff(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF3IUC3_MarkWatershedLineOff(self)
    __swig_destroy__ = _itkMorphologicalWatershedFromMarkersImageFilterPython.delete_itkMorphologicalWatershedFromMarkersImageFilterIF3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMorphologicalWatershedFromMarkersImageFilterIF3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMorphologicalWatershedFromMarkersImageFilterIF3IUC3

        Create a new object of the class itkMorphologicalWatershedFromMarkersImageFilterIF3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMorphologicalWatershedFromMarkersImageFilterIF3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMorphologicalWatershedFromMarkersImageFilterIF3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMorphologicalWatershedFromMarkersImageFilterIF3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMorphologicalWatershedFromMarkersImageFilterIF3IUC3 in _itkMorphologicalWatershedFromMarkersImageFilterPython:
_itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIF3IUC3_swigregister(itkMorphologicalWatershedFromMarkersImageFilterIF3IUC3)

def itkMorphologicalWatershedFromMarkersImageFilterISS2ISS2_New():
    return itkMorphologicalWatershedFromMarkersImageFilterISS2ISS2.New()

class itkMorphologicalWatershedFromMarkersImageFilterISS2ISS2(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS2ISS2):
    r"""Proxy of C++ itkMorphologicalWatershedFromMarkersImageFilterISS2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMorphologicalWatershedFromMarkersImageFilterISS2ISS2_Pointer"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMorphologicalWatershedFromMarkersImageFilterISS2ISS2_Pointer"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS2ISS2_Clone(self)

    def SetMarkerImage(self, input):
        r"""
        SetMarkerImage(self, input)

        Parameters
        ----------
        input: itkImageSS2 const *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS2ISS2_SetMarkerImage(self, input)

    def GetMarkerImage(self):
        r"""GetMarkerImage(self) -> itkImageSS2"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS2ISS2_GetMarkerImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageSS2 const *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS2ISS2_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageSS2 const *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS2ISS2_SetInput2(self, input)

    def SetFullyConnected(self, _arg):
        r"""
        SetFullyConnected(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS2ISS2_SetFullyConnected(self, _arg)

    def GetFullyConnected(self):
        r"""GetFullyConnected(self) -> bool const &"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS2ISS2_GetFullyConnected(self)

    def FullyConnectedOn(self):
        r"""FullyConnectedOn(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS2ISS2_FullyConnectedOn(self)

    def FullyConnectedOff(self):
        r"""FullyConnectedOff(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS2ISS2_FullyConnectedOff(self)

    def SetMarkWatershedLine(self, _arg):
        r"""
        SetMarkWatershedLine(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS2ISS2_SetMarkWatershedLine(self, _arg)

    def GetMarkWatershedLine(self):
        r"""GetMarkWatershedLine(self) -> bool const &"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS2ISS2_GetMarkWatershedLine(self)

    def MarkWatershedLineOn(self):
        r"""MarkWatershedLineOn(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS2ISS2_MarkWatershedLineOn(self)

    def MarkWatershedLineOff(self):
        r"""MarkWatershedLineOff(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS2ISS2_MarkWatershedLineOff(self)
    __swig_destroy__ = _itkMorphologicalWatershedFromMarkersImageFilterPython.delete_itkMorphologicalWatershedFromMarkersImageFilterISS2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMorphologicalWatershedFromMarkersImageFilterISS2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMorphologicalWatershedFromMarkersImageFilterISS2ISS2

        Create a new object of the class itkMorphologicalWatershedFromMarkersImageFilterISS2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMorphologicalWatershedFromMarkersImageFilterISS2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMorphologicalWatershedFromMarkersImageFilterISS2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMorphologicalWatershedFromMarkersImageFilterISS2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMorphologicalWatershedFromMarkersImageFilterISS2ISS2 in _itkMorphologicalWatershedFromMarkersImageFilterPython:
_itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS2ISS2_swigregister(itkMorphologicalWatershedFromMarkersImageFilterISS2ISS2)

def itkMorphologicalWatershedFromMarkersImageFilterISS2IUC2_New():
    return itkMorphologicalWatershedFromMarkersImageFilterISS2IUC2.New()

class itkMorphologicalWatershedFromMarkersImageFilterISS2IUC2(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS2IUC2):
    r"""Proxy of C++ itkMorphologicalWatershedFromMarkersImageFilterISS2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMorphologicalWatershedFromMarkersImageFilterISS2IUC2_Pointer"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMorphologicalWatershedFromMarkersImageFilterISS2IUC2_Pointer"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS2IUC2_Clone(self)

    def SetMarkerImage(self, input):
        r"""
        SetMarkerImage(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS2IUC2_SetMarkerImage(self, input)

    def GetMarkerImage(self):
        r"""GetMarkerImage(self) -> itkImageUC2"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS2IUC2_GetMarkerImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageSS2 const *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS2IUC2_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS2IUC2_SetInput2(self, input)

    def SetFullyConnected(self, _arg):
        r"""
        SetFullyConnected(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS2IUC2_SetFullyConnected(self, _arg)

    def GetFullyConnected(self):
        r"""GetFullyConnected(self) -> bool const &"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS2IUC2_GetFullyConnected(self)

    def FullyConnectedOn(self):
        r"""FullyConnectedOn(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS2IUC2_FullyConnectedOn(self)

    def FullyConnectedOff(self):
        r"""FullyConnectedOff(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS2IUC2_FullyConnectedOff(self)

    def SetMarkWatershedLine(self, _arg):
        r"""
        SetMarkWatershedLine(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS2IUC2_SetMarkWatershedLine(self, _arg)

    def GetMarkWatershedLine(self):
        r"""GetMarkWatershedLine(self) -> bool const &"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS2IUC2_GetMarkWatershedLine(self)

    def MarkWatershedLineOn(self):
        r"""MarkWatershedLineOn(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS2IUC2_MarkWatershedLineOn(self)

    def MarkWatershedLineOff(self):
        r"""MarkWatershedLineOff(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS2IUC2_MarkWatershedLineOff(self)
    __swig_destroy__ = _itkMorphologicalWatershedFromMarkersImageFilterPython.delete_itkMorphologicalWatershedFromMarkersImageFilterISS2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMorphologicalWatershedFromMarkersImageFilterISS2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMorphologicalWatershedFromMarkersImageFilterISS2IUC2

        Create a new object of the class itkMorphologicalWatershedFromMarkersImageFilterISS2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMorphologicalWatershedFromMarkersImageFilterISS2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMorphologicalWatershedFromMarkersImageFilterISS2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMorphologicalWatershedFromMarkersImageFilterISS2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMorphologicalWatershedFromMarkersImageFilterISS2IUC2 in _itkMorphologicalWatershedFromMarkersImageFilterPython:
_itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS2IUC2_swigregister(itkMorphologicalWatershedFromMarkersImageFilterISS2IUC2)

def itkMorphologicalWatershedFromMarkersImageFilterISS3ISS3_New():
    return itkMorphologicalWatershedFromMarkersImageFilterISS3ISS3.New()

class itkMorphologicalWatershedFromMarkersImageFilterISS3ISS3(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS3ISS3):
    r"""Proxy of C++ itkMorphologicalWatershedFromMarkersImageFilterISS3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMorphologicalWatershedFromMarkersImageFilterISS3ISS3_Pointer"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMorphologicalWatershedFromMarkersImageFilterISS3ISS3_Pointer"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS3ISS3_Clone(self)

    def SetMarkerImage(self, input):
        r"""
        SetMarkerImage(self, input)

        Parameters
        ----------
        input: itkImageSS3 const *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS3ISS3_SetMarkerImage(self, input)

    def GetMarkerImage(self):
        r"""GetMarkerImage(self) -> itkImageSS3"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS3ISS3_GetMarkerImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageSS3 const *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS3ISS3_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageSS3 const *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS3ISS3_SetInput2(self, input)

    def SetFullyConnected(self, _arg):
        r"""
        SetFullyConnected(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS3ISS3_SetFullyConnected(self, _arg)

    def GetFullyConnected(self):
        r"""GetFullyConnected(self) -> bool const &"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS3ISS3_GetFullyConnected(self)

    def FullyConnectedOn(self):
        r"""FullyConnectedOn(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS3ISS3_FullyConnectedOn(self)

    def FullyConnectedOff(self):
        r"""FullyConnectedOff(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS3ISS3_FullyConnectedOff(self)

    def SetMarkWatershedLine(self, _arg):
        r"""
        SetMarkWatershedLine(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS3ISS3_SetMarkWatershedLine(self, _arg)

    def GetMarkWatershedLine(self):
        r"""GetMarkWatershedLine(self) -> bool const &"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS3ISS3_GetMarkWatershedLine(self)

    def MarkWatershedLineOn(self):
        r"""MarkWatershedLineOn(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS3ISS3_MarkWatershedLineOn(self)

    def MarkWatershedLineOff(self):
        r"""MarkWatershedLineOff(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS3ISS3_MarkWatershedLineOff(self)
    __swig_destroy__ = _itkMorphologicalWatershedFromMarkersImageFilterPython.delete_itkMorphologicalWatershedFromMarkersImageFilterISS3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMorphologicalWatershedFromMarkersImageFilterISS3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMorphologicalWatershedFromMarkersImageFilterISS3ISS3

        Create a new object of the class itkMorphologicalWatershedFromMarkersImageFilterISS3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMorphologicalWatershedFromMarkersImageFilterISS3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMorphologicalWatershedFromMarkersImageFilterISS3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMorphologicalWatershedFromMarkersImageFilterISS3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMorphologicalWatershedFromMarkersImageFilterISS3ISS3 in _itkMorphologicalWatershedFromMarkersImageFilterPython:
_itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS3ISS3_swigregister(itkMorphologicalWatershedFromMarkersImageFilterISS3ISS3)

def itkMorphologicalWatershedFromMarkersImageFilterISS3IUC3_New():
    return itkMorphologicalWatershedFromMarkersImageFilterISS3IUC3.New()

class itkMorphologicalWatershedFromMarkersImageFilterISS3IUC3(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS3IUC3):
    r"""Proxy of C++ itkMorphologicalWatershedFromMarkersImageFilterISS3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMorphologicalWatershedFromMarkersImageFilterISS3IUC3_Pointer"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMorphologicalWatershedFromMarkersImageFilterISS3IUC3_Pointer"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS3IUC3_Clone(self)

    def SetMarkerImage(self, input):
        r"""
        SetMarkerImage(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS3IUC3_SetMarkerImage(self, input)

    def GetMarkerImage(self):
        r"""GetMarkerImage(self) -> itkImageUC3"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS3IUC3_GetMarkerImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageSS3 const *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS3IUC3_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS3IUC3_SetInput2(self, input)

    def SetFullyConnected(self, _arg):
        r"""
        SetFullyConnected(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS3IUC3_SetFullyConnected(self, _arg)

    def GetFullyConnected(self):
        r"""GetFullyConnected(self) -> bool const &"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS3IUC3_GetFullyConnected(self)

    def FullyConnectedOn(self):
        r"""FullyConnectedOn(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS3IUC3_FullyConnectedOn(self)

    def FullyConnectedOff(self):
        r"""FullyConnectedOff(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS3IUC3_FullyConnectedOff(self)

    def SetMarkWatershedLine(self, _arg):
        r"""
        SetMarkWatershedLine(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS3IUC3_SetMarkWatershedLine(self, _arg)

    def GetMarkWatershedLine(self):
        r"""GetMarkWatershedLine(self) -> bool const &"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS3IUC3_GetMarkWatershedLine(self)

    def MarkWatershedLineOn(self):
        r"""MarkWatershedLineOn(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS3IUC3_MarkWatershedLineOn(self)

    def MarkWatershedLineOff(self):
        r"""MarkWatershedLineOff(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS3IUC3_MarkWatershedLineOff(self)
    __swig_destroy__ = _itkMorphologicalWatershedFromMarkersImageFilterPython.delete_itkMorphologicalWatershedFromMarkersImageFilterISS3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMorphologicalWatershedFromMarkersImageFilterISS3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMorphologicalWatershedFromMarkersImageFilterISS3IUC3

        Create a new object of the class itkMorphologicalWatershedFromMarkersImageFilterISS3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMorphologicalWatershedFromMarkersImageFilterISS3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMorphologicalWatershedFromMarkersImageFilterISS3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMorphologicalWatershedFromMarkersImageFilterISS3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMorphologicalWatershedFromMarkersImageFilterISS3IUC3 in _itkMorphologicalWatershedFromMarkersImageFilterPython:
_itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterISS3IUC3_swigregister(itkMorphologicalWatershedFromMarkersImageFilterISS3IUC3)

def itkMorphologicalWatershedFromMarkersImageFilterIUC2ISS2_New():
    return itkMorphologicalWatershedFromMarkersImageFilterIUC2ISS2.New()

class itkMorphologicalWatershedFromMarkersImageFilterIUC2ISS2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC2ISS2):
    r"""Proxy of C++ itkMorphologicalWatershedFromMarkersImageFilterIUC2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMorphologicalWatershedFromMarkersImageFilterIUC2ISS2_Pointer"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMorphologicalWatershedFromMarkersImageFilterIUC2ISS2_Pointer"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC2ISS2_Clone(self)

    def SetMarkerImage(self, input):
        r"""
        SetMarkerImage(self, input)

        Parameters
        ----------
        input: itkImageSS2 const *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC2ISS2_SetMarkerImage(self, input)

    def GetMarkerImage(self):
        r"""GetMarkerImage(self) -> itkImageSS2"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC2ISS2_GetMarkerImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC2ISS2_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageSS2 const *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC2ISS2_SetInput2(self, input)

    def SetFullyConnected(self, _arg):
        r"""
        SetFullyConnected(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC2ISS2_SetFullyConnected(self, _arg)

    def GetFullyConnected(self):
        r"""GetFullyConnected(self) -> bool const &"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC2ISS2_GetFullyConnected(self)

    def FullyConnectedOn(self):
        r"""FullyConnectedOn(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC2ISS2_FullyConnectedOn(self)

    def FullyConnectedOff(self):
        r"""FullyConnectedOff(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC2ISS2_FullyConnectedOff(self)

    def SetMarkWatershedLine(self, _arg):
        r"""
        SetMarkWatershedLine(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC2ISS2_SetMarkWatershedLine(self, _arg)

    def GetMarkWatershedLine(self):
        r"""GetMarkWatershedLine(self) -> bool const &"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC2ISS2_GetMarkWatershedLine(self)

    def MarkWatershedLineOn(self):
        r"""MarkWatershedLineOn(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC2ISS2_MarkWatershedLineOn(self)

    def MarkWatershedLineOff(self):
        r"""MarkWatershedLineOff(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC2ISS2_MarkWatershedLineOff(self)
    __swig_destroy__ = _itkMorphologicalWatershedFromMarkersImageFilterPython.delete_itkMorphologicalWatershedFromMarkersImageFilterIUC2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMorphologicalWatershedFromMarkersImageFilterIUC2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMorphologicalWatershedFromMarkersImageFilterIUC2ISS2

        Create a new object of the class itkMorphologicalWatershedFromMarkersImageFilterIUC2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMorphologicalWatershedFromMarkersImageFilterIUC2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMorphologicalWatershedFromMarkersImageFilterIUC2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMorphologicalWatershedFromMarkersImageFilterIUC2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMorphologicalWatershedFromMarkersImageFilterIUC2ISS2 in _itkMorphologicalWatershedFromMarkersImageFilterPython:
_itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC2ISS2_swigregister(itkMorphologicalWatershedFromMarkersImageFilterIUC2ISS2)

def itkMorphologicalWatershedFromMarkersImageFilterIUC2IUC2_New():
    return itkMorphologicalWatershedFromMarkersImageFilterIUC2IUC2.New()

class itkMorphologicalWatershedFromMarkersImageFilterIUC2IUC2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC2IUC2):
    r"""Proxy of C++ itkMorphologicalWatershedFromMarkersImageFilterIUC2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMorphologicalWatershedFromMarkersImageFilterIUC2IUC2_Pointer"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMorphologicalWatershedFromMarkersImageFilterIUC2IUC2_Pointer"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC2IUC2_Clone(self)

    def SetMarkerImage(self, input):
        r"""
        SetMarkerImage(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC2IUC2_SetMarkerImage(self, input)

    def GetMarkerImage(self):
        r"""GetMarkerImage(self) -> itkImageUC2"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC2IUC2_GetMarkerImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC2IUC2_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC2IUC2_SetInput2(self, input)

    def SetFullyConnected(self, _arg):
        r"""
        SetFullyConnected(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC2IUC2_SetFullyConnected(self, _arg)

    def GetFullyConnected(self):
        r"""GetFullyConnected(self) -> bool const &"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC2IUC2_GetFullyConnected(self)

    def FullyConnectedOn(self):
        r"""FullyConnectedOn(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC2IUC2_FullyConnectedOn(self)

    def FullyConnectedOff(self):
        r"""FullyConnectedOff(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC2IUC2_FullyConnectedOff(self)

    def SetMarkWatershedLine(self, _arg):
        r"""
        SetMarkWatershedLine(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC2IUC2_SetMarkWatershedLine(self, _arg)

    def GetMarkWatershedLine(self):
        r"""GetMarkWatershedLine(self) -> bool const &"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC2IUC2_GetMarkWatershedLine(self)

    def MarkWatershedLineOn(self):
        r"""MarkWatershedLineOn(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC2IUC2_MarkWatershedLineOn(self)

    def MarkWatershedLineOff(self):
        r"""MarkWatershedLineOff(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC2IUC2_MarkWatershedLineOff(self)
    __swig_destroy__ = _itkMorphologicalWatershedFromMarkersImageFilterPython.delete_itkMorphologicalWatershedFromMarkersImageFilterIUC2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMorphologicalWatershedFromMarkersImageFilterIUC2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMorphologicalWatershedFromMarkersImageFilterIUC2IUC2

        Create a new object of the class itkMorphologicalWatershedFromMarkersImageFilterIUC2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMorphologicalWatershedFromMarkersImageFilterIUC2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMorphologicalWatershedFromMarkersImageFilterIUC2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMorphologicalWatershedFromMarkersImageFilterIUC2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMorphologicalWatershedFromMarkersImageFilterIUC2IUC2 in _itkMorphologicalWatershedFromMarkersImageFilterPython:
_itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC2IUC2_swigregister(itkMorphologicalWatershedFromMarkersImageFilterIUC2IUC2)

def itkMorphologicalWatershedFromMarkersImageFilterIUC3ISS3_New():
    return itkMorphologicalWatershedFromMarkersImageFilterIUC3ISS3.New()

class itkMorphologicalWatershedFromMarkersImageFilterIUC3ISS3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC3ISS3):
    r"""Proxy of C++ itkMorphologicalWatershedFromMarkersImageFilterIUC3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMorphologicalWatershedFromMarkersImageFilterIUC3ISS3_Pointer"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMorphologicalWatershedFromMarkersImageFilterIUC3ISS3_Pointer"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC3ISS3_Clone(self)

    def SetMarkerImage(self, input):
        r"""
        SetMarkerImage(self, input)

        Parameters
        ----------
        input: itkImageSS3 const *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC3ISS3_SetMarkerImage(self, input)

    def GetMarkerImage(self):
        r"""GetMarkerImage(self) -> itkImageSS3"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC3ISS3_GetMarkerImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC3ISS3_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageSS3 const *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC3ISS3_SetInput2(self, input)

    def SetFullyConnected(self, _arg):
        r"""
        SetFullyConnected(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC3ISS3_SetFullyConnected(self, _arg)

    def GetFullyConnected(self):
        r"""GetFullyConnected(self) -> bool const &"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC3ISS3_GetFullyConnected(self)

    def FullyConnectedOn(self):
        r"""FullyConnectedOn(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC3ISS3_FullyConnectedOn(self)

    def FullyConnectedOff(self):
        r"""FullyConnectedOff(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC3ISS3_FullyConnectedOff(self)

    def SetMarkWatershedLine(self, _arg):
        r"""
        SetMarkWatershedLine(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC3ISS3_SetMarkWatershedLine(self, _arg)

    def GetMarkWatershedLine(self):
        r"""GetMarkWatershedLine(self) -> bool const &"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC3ISS3_GetMarkWatershedLine(self)

    def MarkWatershedLineOn(self):
        r"""MarkWatershedLineOn(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC3ISS3_MarkWatershedLineOn(self)

    def MarkWatershedLineOff(self):
        r"""MarkWatershedLineOff(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC3ISS3_MarkWatershedLineOff(self)
    __swig_destroy__ = _itkMorphologicalWatershedFromMarkersImageFilterPython.delete_itkMorphologicalWatershedFromMarkersImageFilterIUC3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMorphologicalWatershedFromMarkersImageFilterIUC3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMorphologicalWatershedFromMarkersImageFilterIUC3ISS3

        Create a new object of the class itkMorphologicalWatershedFromMarkersImageFilterIUC3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMorphologicalWatershedFromMarkersImageFilterIUC3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMorphologicalWatershedFromMarkersImageFilterIUC3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMorphologicalWatershedFromMarkersImageFilterIUC3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMorphologicalWatershedFromMarkersImageFilterIUC3ISS3 in _itkMorphologicalWatershedFromMarkersImageFilterPython:
_itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC3ISS3_swigregister(itkMorphologicalWatershedFromMarkersImageFilterIUC3ISS3)

def itkMorphologicalWatershedFromMarkersImageFilterIUC3IUC3_New():
    return itkMorphologicalWatershedFromMarkersImageFilterIUC3IUC3.New()

class itkMorphologicalWatershedFromMarkersImageFilterIUC3IUC3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC3IUC3):
    r"""Proxy of C++ itkMorphologicalWatershedFromMarkersImageFilterIUC3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMorphologicalWatershedFromMarkersImageFilterIUC3IUC3_Pointer"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMorphologicalWatershedFromMarkersImageFilterIUC3IUC3_Pointer"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC3IUC3_Clone(self)

    def SetMarkerImage(self, input):
        r"""
        SetMarkerImage(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC3IUC3_SetMarkerImage(self, input)

    def GetMarkerImage(self):
        r"""GetMarkerImage(self) -> itkImageUC3"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC3IUC3_GetMarkerImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC3IUC3_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC3IUC3_SetInput2(self, input)

    def SetFullyConnected(self, _arg):
        r"""
        SetFullyConnected(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC3IUC3_SetFullyConnected(self, _arg)

    def GetFullyConnected(self):
        r"""GetFullyConnected(self) -> bool const &"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC3IUC3_GetFullyConnected(self)

    def FullyConnectedOn(self):
        r"""FullyConnectedOn(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC3IUC3_FullyConnectedOn(self)

    def FullyConnectedOff(self):
        r"""FullyConnectedOff(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC3IUC3_FullyConnectedOff(self)

    def SetMarkWatershedLine(self, _arg):
        r"""
        SetMarkWatershedLine(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC3IUC3_SetMarkWatershedLine(self, _arg)

    def GetMarkWatershedLine(self):
        r"""GetMarkWatershedLine(self) -> bool const &"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC3IUC3_GetMarkWatershedLine(self)

    def MarkWatershedLineOn(self):
        r"""MarkWatershedLineOn(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC3IUC3_MarkWatershedLineOn(self)

    def MarkWatershedLineOff(self):
        r"""MarkWatershedLineOff(self)"""
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC3IUC3_MarkWatershedLineOff(self)
    __swig_destroy__ = _itkMorphologicalWatershedFromMarkersImageFilterPython.delete_itkMorphologicalWatershedFromMarkersImageFilterIUC3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMorphologicalWatershedFromMarkersImageFilterIUC3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMorphologicalWatershedFromMarkersImageFilterIUC3IUC3

        Create a new object of the class itkMorphologicalWatershedFromMarkersImageFilterIUC3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMorphologicalWatershedFromMarkersImageFilterIUC3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMorphologicalWatershedFromMarkersImageFilterIUC3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMorphologicalWatershedFromMarkersImageFilterIUC3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMorphologicalWatershedFromMarkersImageFilterIUC3IUC3 in _itkMorphologicalWatershedFromMarkersImageFilterPython:
_itkMorphologicalWatershedFromMarkersImageFilterPython.itkMorphologicalWatershedFromMarkersImageFilterIUC3IUC3_swigregister(itkMorphologicalWatershedFromMarkersImageFilterIUC3IUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def morphological_watershed_from_markers_image_filter(*args: itkt.ImageLike,  marker_image: itkt.Image=..., fully_connected: bool=..., mark_watershed_line: bool=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for MorphologicalWatershedFromMarkersImageFilter"""
    import itk

    kwarg_typehints = { 'marker_image':marker_image,'fully_connected':fully_connected,'mark_watershed_line':mark_watershed_line }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.MorphologicalWatershedFromMarkersImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def morphological_watershed_from_markers_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKWatersheds.MorphologicalWatershedFromMarkersImageFilter
    morphological_watershed_from_markers_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    morphological_watershed_from_markers_image_filter.__doc__ = filter_object.__doc__



